---
title: '[공지] 나이스페이 자체 장애 대응 완료(종결)'
category: 공지사항
tags:
  - 나이스페이먼츠
  - 공지사항
pgCompanies:
  - null
datetime: 2023-09-06T15:00:00.000Z
---

안녕하세요, 포트원 고객지원팀입니다.

금일 (2023-09-07) 발생되었던 나이스페이 PG사측의 장애가 종결(포트원 대응완료)되어 공지드립니다.

자세한 사항은 아래 상세 내용을 참고 부탁드리겠습니다.

**상세내용**

- 영향 : (신)나이스페이 이용 고객사
- 원인: (신)나이스페이 PG사에서 페이코 '잔액 부족' 응답 메세지에 대한 메시지 형식이 올바르지 않아 처리 과정 중 오류 발생
- 영향 내용: 실제 고객은 결제 됐는데 포트원에 결제 실패로 기록됨
- 대응 : (신)나이스페이 장애 대응을 위한 포트원 작업 진행 및 대응완료

해당 이슈는 나이스페이측에서 대응이 어려운 것으로 확인되어 당사에서 긴급 조치 및 대응 완료되어 이슈 해결되었습니다.

감사합니다.

포트원(PortOne) 드림
